marquee - a program to scroll the text delivered to its standard input.

Examples:

```
$ echo "The big brown fox jumps over a lazy dog" | sscroll -l 10 -F '[{0}]' -n
[The big br]
[he big bro]
[e big brow]
```

* [example usage](https://asciinema.org/a/146656)
* [dynamic change of displayed text](https://asciinema.org/a/146654)
